( cd opt/kde/share/doc/HTML/da/k3b ; rm -rf common )
( cd opt/kde/share/doc/HTML/da/k3b ; ln -sf /opt/kde/share/doc/HTML/da/common common )
( cd opt/kde/share/doc/HTML/de/k3b ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/k3b ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/es/k3b ; rm -rf common )
( cd opt/kde/share/doc/HTML/es/k3b ; ln -sf /opt/kde/share/doc/HTML/es/common common )
( cd opt/kde/share/doc/HTML/et/k3b ; rm -rf common )
( cd opt/kde/share/doc/HTML/et/k3b ; ln -sf /opt/kde/share/doc/HTML/et/common common )
( cd opt/kde/share/doc/HTML/fr/k3b ; rm -rf common )
( cd opt/kde/share/doc/HTML/fr/k3b ; ln -sf /opt/kde/share/doc/HTML/fr/common common )
( cd opt/kde/share/doc/HTML/pt/k3b ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt/k3b ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
( cd opt/kde/share/doc/HTML/ru/k3b ; rm -rf common )
( cd opt/kde/share/doc/HTML/ru/k3b ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
( cd opt/kde/share/doc/HTML/sv/k3b ; rm -rf common )
( cd opt/kde/share/doc/HTML/sv/k3b ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
